==> enterprisemodules-wls_config-3.0.21.tar.gz: enterprisemodules-wls_config-3.0.21/meta/wls_jms_template.py <==
username      = sys.argv[1]
password      = sys.argv[2]
url           = sys.argv[3]

connect(username, password, url)

execfile('/vagrant/files/wlst/common.py.erb')
execfile('/vagrant/meta/get_properties.py')

print 'base properties'
properties('/JMSSystemResources/jmsClusterModule/JMSResource/jmsClusterModule/Templates/Template-0','wls_jms_template')  # All default properties
print 'DeliveryFailureParams'
properties('/JMSSystemResources/jmsClusterModule/JMSResource/jmsClusterModule/Templates/Template-0/DeliveryFailureParams/Template-0','wls_jms_template', 'delivery_', 'DeliveryFailureParams/%{template_name}/')  # All default properties
print 'MessageLoggingParams'
properties('/JMSSystemResources/jmsClusterModule/JMSResource/jmsClusterModule/Templates/Template-0/MessageLoggingParams/Template-0','wls_jms_template', 'log_', 'MessageLoggingParams/%{template_name}/')  # All default properties
print 'DeliveryParamsOverrides'
properties('/JMSSystemResources/jmsClusterModule/JMSResource/jmsClusterModule/Templates/Template-0/DeliveryParamsOverrides/Template-0','wls_jms_template', 'override_', 'DeliveryParamsOverrides/%{template_name}/')  # All default properties
print 'Thresholds'
properties('/JMSSystemResources/jmsClusterModule/JMSResource/jmsClusterModule/Templates/Template-0/Thresholds/Template-0','wls_jms_template', 'thresholds_', 'Thresholds/%{template_name}/')  # All default properties
print 'GroupParams'
properties('/JMSSystemResources/jmsClusterModule/JMSResource/jmsClusterModule/Templates/Template-0/GroupParams/Template-0','wls_jms_template', 'group_', 'GroupParams/%{template_name}/')  # All default properties
print 'Multicast'
properties('/JMSSystemResources/jmsClusterModule/JMSResource/jmsClusterModule/Templates/Template-0/Multicast/Template-0','wls_jms_template', 'group_', 'Multicast/%{template_name}/')  # All default properties
print 'Quota'
properties('/JMSSystemResources/jmsClusterModule/JMSResource/jmsClusterModule/Templates/Template-0/Quota/Template-0','wls_jms_template', 'group_', 'Quota/%{template_name}/')  # All default properties

==> enterprisemodules-wls_config-3.3.15.tar.gz: enterprisemodules-wls_config-3.3.15/meta/wls_jms_template.py <==
username      = sys.argv[1]
password      = sys.argv[2]
url           = sys.argv[3]

connect(username, password, url)

execfile('/etc/puppetlabs/code/environments/production/modules/wls_config//lib/puppet/provider/wls_config/wlst/templates/common.py.erb')
execfile('/etc/puppetlabs/code/environments/production/modules/wls_config/meta/get_properties.py')

print 'base properties'
properties('/JMSSystemResources/jmsClusterModule/JMSResource/jmsClusterModule/Templates/Template-0','wls_jms_template')  # All default properties
print 'DeliveryFailureParams'
properties('/JMSSystemResources/jmsClusterModule/JMSResource/jmsClusterModule/Templates/Template-0/DeliveryFailureParams/Template-0','wls_jms_template', 'delivery_', 'DeliveryFailureParams/%{template_name}/')  # All default properties
print 'MessageLoggingParams'
properties('/JMSSystemResources/jmsClusterModule/JMSResource/jmsClusterModule/Templates/Template-0/MessageLoggingParams/Template-0','wls_jms_template', 'log_', 'MessageLoggingParams/%{template_name}/')  # All default properties
print 'DeliveryParamsOverrides'
properties('/JMSSystemResources/jmsClusterModule/JMSResource/jmsClusterModule/Templates/Template-0/DeliveryParamsOverrides/Template-0','wls_jms_template', 'override_', 'DeliveryParamsOverrides/%{template_name}/')  # All default properties
print 'Thresholds'
properties('/JMSSystemResources/jmsClusterModule/JMSResource/jmsClusterModule/Templates/Template-0/Thresholds/Template-0','wls_jms_template', 'thresholds_', 'Thresholds/%{template_name}/')  # All default properties
print 'GroupParams'
properties('/JMSSystemResources/jmsClusterModule/JMSResource/jmsClusterModule/Templates/Template-0/GroupParams/Template-0','wls_jms_template', 'group_', 'GroupParams/%{template_name}/')  # All default properties
print 'Multicast'
properties('/JMSSystemResources/jmsClusterModule/JMSResource/jmsClusterModule/Templates/Template-0/Multicast/Template-0','wls_jms_template', 'group_', 'Multicast/%{template_name}/')  # All default properties
print 'Quota'
properties('/JMSSystemResources/jmsClusterModule/JMSResource/jmsClusterModule/Templates/Template-0/Quota/Template-0','wls_jms_template', 'group_', 'Quota/%{template_name}/')  # All default properties
